// RELATED SOFTWARE: Scilab >= 5.5.0
// PACKAGE  : gui2bitmap() : https://atoms.scilab.org/toolboxes/gui2bitmap
// VERSION  : 1.2 - 2019-08-09
// AUTHOR   : Samuel GOUGEON
// COPYRIGHT: Samuel GOUGEON - 2019
// LICENSE  : CeCILL : http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
//
// <-- INTERACTIVE TEST -->
// ===========================================================================
// Unitary INTERACTIVE tests for gui2bitmap()
// ==========================================
//
Dir = TMPDIR + "/gui2bitmap/";
mkdir(Dir);
close(winsid())
gui2bitmap("setBorders",[%T %T %T]);

if getos()<>"Windows" then
    function see(a); endfunction
else
    see = winopen
end
exec("SCI/modules/gui/demos/uicontrol_plot3d.dem.sce",-1);
f = gcf();
sleep(1000);

// The whole figure on the screen
// ==============================
title("Whole on the screen / no borders");
im = Dir+"whole_on_screen_no_borders.png";
gui2bitmap(f, im);
see(im)

title("Whole on the screen / with borders");
im = Dir+"whole_on_screen_with_borders.png";
gui2bitmap(f, im, %t);
see(im)


// Figure partly off-screen
// ========================
f.figure_position = [-300, 600];
sleep(500)
title("Partly off-screen / no borders");
im = Dir+"partly_offscreen_no_borders.png";
gui2bitmap(f, im);
see(im)

title("Partly off-screen / with borders");
im = Dir+"partly_offscreen_with_borders.png";
gui2bitmap(f, im, %t);
see(im)


// setBorders
// ==========
gui2bitmap("setBorders",[%F %F %F]);
title("Borders: left-bottom-right trimmed");
im = Dir+"borders_LBR_removed.png";
gui2bitmap(f, im, %t);
gui2bitmap("setBorders",[%T %T %T]);


// setMenu
// =======
// In the console
// --------------
xdel(winsid()) // we delete all graphic windows
    // First figure
plot           
    // second figure, the active one
exec("SCI/modules/gui/demos/uicontrol_plot3d.dem.sce",-1); 
    // create the menu
gui2bitmap("setMenu",get(0)) // check it in the console's menu bar
    // Now use the menu:
    // => the plot3d GUI must appears in the front, and twinkle twice
    // => then the file browser must open
    //    It must start in the current working directory
close() // There is now only one graphic window
    // use the gui2bitmap menu
    // => the plot sample must appears in the front, WITHOUT twinkling
    // => then the file browser must open, etc..

// In a figure
// -----------
xdel(winsid()) // we delete all graphic windows
f = scf();
plot           
gui2bitmap("setMenu", f)
// Check that in the plot window, the last item of the "File" menu is "gui2bitmap"
// Use it => the file browser must open and start in the current working directory

// As a submenu of a uimenu
// ------------------------
// Test to write


// Figure maximized
// ================
xdel(winsid())
exec("SCI/modules/gui/demos/uicontrol_plot3d.dem.sce",-1);
f = gcf();
title("Maximized / no borders");
im = Dir+"maximized_no_borders.png";
messagebox(["After pressing OK,";
            "Please maximize the GUI";
            "to fit the whole screen";
            "Then press any key in the console"]);
halt("Press any key to run gui2bitmap: ")
gui2bitmap(f, im);
see(im)

title("Maximized / with borders");
im = Dir+"maximized_with_borders.png";
gui2bitmap(f, im, %t);
see(im)

